@@ -39,10 +39,10 @@ as_roxygen_docs <- function(
     sprintf("    options::opt(x, default, env = \"%s\")", pkg),
     "",
 
-    "@seealso options getOption Sys.getenv Sys.getenv",
+    "@seealso options getOption Sys.setenv Sys.getenv",
     "@section Options:",
     "\\describe{",
-    vapply(setdiff(names(optenv), CONST_OPTIONS_META), function(n) {
+    vapply(setdiff(names(details), CONST_OPTIONS_META), function(n) {
       sprintf(
         "\\item{%s}{\\describe{%s}}\n", n,
         paste0(
